Best-fit clawdb wrapper over the currently published component crates.
Re-exports
pub use crate::config::ClawDBConfig;
Structs
- ClawDB
- Unified database wrapper built from the current component crates.
- ClawDB
Session - Public session type returned by the wrapper.
Type Aliases
- ClawDB
Engine - Compatibility alias.